@@ -806,6 +806,7 @@ def checkFormatEntries(dtl_tools):
 \Format lyx20x     20.lyx "LyX 2.0.x"             "" ""	""	"document"	""
 \Format lyx21x     21.lyx "LyX 2.1.x"             "" ""	""	"document"	""
 \Format lyx22x     22.lyx "LyX 2.2.x"             "" ""	""	"document,menu=export"	""
+\Format lyx24x     24.lyx "LyX 2.4.x"             "" ""	""	"document,menu=export"	""
 \Format clyx       cjklyx "CJK LyX 1.4.x (big5)"  "" ""	""	"document"	""
 \Format jlyx       cjklyx "CJK LyX 1.4.x (euc-jp)" "" ""	""	"document"	""
 \Format klyx       cjklyx "CJK LyX 1.4.x (euc-kr)" "" ""	""	"document"	""
@@ -1198,15 +1199,15 @@ def checkConverterEntries():
             version_number = match.groups()[0]
             version = version_number.split('.')
             if int(version[0]) > 2 or (len(version) > 1 and int(version[0]) == 2 and int(version[1]) >= 11):
-                addToRC(r'''\converter lilypond   eps        "lilypond -dbackend=eps -dsafe --ps $$i"	""
-\converter lilypond   png        "lilypond -dbackend=eps -dsafe --png $$i"	""''')
-                addToRC(r'\converter lilypond   pdf6       "lilypond -dbackend=eps -dsafe --pdf $$i"	""')
+                addToRC(r'''\converter lilypond   eps        "lilypond -dbackend=eps --ps $$i"	"needauth"
+\converter lilypond   png        "lilypond -dbackend=eps --png $$i"	"needauth"''')
+                addToRC(r'\converter lilypond   pdf6       "lilypond -dbackend=eps --pdf $$i"	"needauth"')
                 logger.info('+  found LilyPond version %s.' % version_number)
             elif int(version[0]) > 2 or (len(version) > 1 and int(version[0]) == 2 and int(version[1]) >= 6):
-                addToRC(r'''\converter lilypond   eps        "lilypond -b eps --ps --safe $$i"	""
+                addToRC(r'''\converter lilypond   eps        "lilypond -b eps --ps $$i"	"needauth"
 \converter lilypond   png        "lilypond -b eps --png $$i"	""''')
                 if int(version[0]) > 2 or (len(version) > 1 and int(version[0]) == 2 and int(version[1]) >= 9):
-                    addToRC(r'\converter lilypond   pdf6       "lilypond -b eps --pdf --safe $$i"	""')
+                    addToRC(r'\converter lilypond   pdf6       "lilypond -b eps --pdf $$i"	"needauth"')
                 logger.info('+  found LilyPond version %s.' % version_number)
             else:
                 logger.info('+  found LilyPond, but version %s is too old.' % version_number)
@@ -1228,12 +1229,12 @@ def checkConverterEntries():
                 #       even when requested with --pdf. This is a problem if a user
                 #       clicks View PDF after having done a View DVI. To circumvent
                 #       this, use different output folders for eps and pdf outputs.
-                addToRC(r'\converter lilypond-book latex    "lilypond-book --safe --lily-output-dir=ly-eps $$i"                                ""')
-                addToRC(r'\converter lilypond-book pdflatex "lilypond-book --safe --pdf --latex-program=pdflatex --lily-output-dir=ly-pdf $$i" ""')
-                addToRC(r'\converter lilypond-book-ja platex "lilypond-book --safe --pdf --latex-program=platex --lily-output-dir=ly-pdf $$i" ""')
-                addToRC(r'\converter lilypond-book xetex    "lilypond-book --safe --pdf --latex-program=xelatex --lily-output-dir=ly-pdf $$i"  ""')
-                addToRC(r'\converter lilypond-book luatex   "lilypond-book --safe --pdf --latex-program=lualatex --lily-output-dir=ly-pdf $$i" ""')
-                addToRC(r'\converter lilypond-book dviluatex "lilypond-book --safe --latex-program=dvilualatex --lily-output-dir=ly-eps $$i" ""')
+                addToRC(r'\converter lilypond-book latex    "lilypond-book --lily-output-dir=ly-eps $$i"                                "needauth"')
+                addToRC(r'\converter lilypond-book pdflatex "lilypond-book --pdf --latex-program=pdflatex --lily-output-dir=ly-pdf $$i" "needauth"')
+                addToRC(r'\converter lilypond-book-ja platex "lilypond-book --pdf --latex-program=platex --lily-output-dir=ly-pdf $$i" "needauth"')
+                addToRC(r'\converter lilypond-book xetex    "lilypond-book --pdf --latex-program=xelatex --lily-output-dir=ly-pdf $$i"  "needauth"')
+                addToRC(r'\converter lilypond-book luatex   "lilypond-book --pdf --latex-program=lualatex --lily-output-dir=ly-pdf $$i" "needauth"')
+                addToRC(r'\converter lilypond-book dviluatex "lilypond-book --latex-program=dvilualatex --lily-output-dir=ly-eps $$i" "needauth"')
                 logger.info('+  found LilyPond-book version %s.' % version_number)
             else:
                 logger.info('+  found LilyPond-book, but version %s is too old.' % version_number)
@@ -1270,6 +1271,7 @@ def checkConverterEntries():
 \converter lyx        lyx20x     "python -tt $$s/lyx2lyx/lyx2lyx -V 2.0 -o $$o $$i"	""
 \converter lyx        lyx21x     "python -tt $$s/lyx2lyx/lyx2lyx -V 2.1 -o $$o $$i"	""
 \converter lyx        lyx22x     "python -tt $$s/lyx2lyx/lyx2lyx -V 2.2 -o $$o $$i"	""
+\converter lyx        lyx24x     "python -tt $$s/lyx2lyx/lyx2lyx -V 2.4 -o $$o $$i"	""
 \converter lyx        clyx       "python -tt $$s/lyx2lyx/lyx2lyx -V 1.4 -o $$o -c big5   $$i"	""
 \converter lyx        jlyx       "python -tt $$s/lyx2lyx/lyx2lyx -V 1.4 -o $$o -c euc_jp $$i"	""
 \converter lyx        klyx       "python -tt $$s/lyx2lyx/lyx2lyx -V 1.4 -o $$o -c euc_kr $$i"	""
