@@ -1149,13 +1149,9 @@ docstring BibTeXInfo::getValueForKey(string const & oldkey, Buffer const & buf,
 namespace {
 
 // A functor for use with sort, leading to case insensitive sorting
-class compareNoCase: public binary_function<docstring, docstring, bool>
-{
-public:
-	bool operator()(docstring const & s1, docstring const & s2) const {
-		return compare_no_case(s1, s2) < 0;
-	}
-};
+bool compareNoCase(const docstring & a, const docstring & b) {
+	return compare_no_case(a, b) < 0;
+}
 
 } // namespace
 
@@ -1206,7 +1202,7 @@ vector<docstring> const BiblioInfo::getKeys() const
 	BiblioInfo::const_iterator it  = begin();
 	for (; it != end(); ++it)
 		bibkeys.push_back(it->first);
-	sort(bibkeys.begin(), bibkeys.end(), compareNoCase());
+	sort(bibkeys.begin(), bibkeys.end(), &compareNoCase);
 	return bibkeys;
 }
 
