@@ -176,6 +176,7 @@ LyXErr & operator<<(LyXErr & os, CursorData const & cur)
 Cursor::Cursor(BufferView & bv)
 	: CursorData(&bv.buffer()), bv_(&bv),
 	  x_target_(-1), textTargetOffset_(0),
+	  x_clickpos_(-1), y_clickpos_(-1), 
 	  beforeDispatchPosX_(0), beforeDispatchPosY_(0)
 {}
 
@@ -1093,6 +1094,13 @@ void Cursor::updateTextTargetOffset()
 }
 
 
+void Cursor::setClickPos(int x, int y)
+{
+	x_clickpos_ = x;
+	y_clickpos_ = y;
+}
+
+
 void Cursor::info(odocstream & os, bool devel_mode) const
 {
 	for (int i = 1, n = depth(); i < n; ++i) {
