@@ -151,6 +151,7 @@ public:
 		BASECLASS, //>This is a base class, i.e., top-level layout file
 		MERGE, //>This is a file included in a layout file
 		MODULE, //>This is a layout module
+		CITE_ENGINE, //>This is a cite engine
 		VALIDATION //>We're just validating
 	};
 	/// return values for read()
@@ -171,7 +172,8 @@ public:
 	ReturnValues read(Lexer & lex, ReadType rt = BASECLASS);
 	/// validates the layout information passed in str
 	static ReturnValues validate(std::string const & str);
-	///
+	/// \return the conversion of \param str to the latest layout format
+	/// compatible with the lyx format.
 	static std::string convert(std::string const & str);
 
 	///////////////////////////////////////////////////////////////////
@@ -205,8 +207,16 @@ public:
 	OutputType outputType() const { return outputType_; }
 	/// Can be latex, docbook ... (the name of a format)
 	std::string outputFormat() const { return outputFormat_; }
-	///
-	docstring outlinerName(std::string const & type) const;
+	/// Does this class redefine the output format?
+	bool hasOutputFormat() const { return has_output_format_; }
+	/// Return the non-localised names for the toc types.
+	std::map<std::string, docstring> const &
+		outlinerNames() const { return outliner_names_; }
+	/// \returns Layout named \p name if it exists, otherwise 0
+	Layout const * getLayout(docstring const & name) const;
+	/// \returns Layout named \p name if it exists, otherwise 0
+	Layout * getLayout(docstring const & name);
+
 protected:
 	/// Protect construction
 	TextClass();
@@ -260,6 +270,8 @@ protected:
 	mutable std::string prerequisites_;
 	/// The possible cite engine types
 	std::string opt_enginetype_;
+	/// The cite framework (bibtex, biblatex)
+	std::string citeframework_;
 	///
 	std::string opt_fontsize_;
 	///
@@ -307,6 +319,8 @@ protected:
 	OutputType outputType_;
 	/// Can be latex, docbook ... (the name of a format)
 	std::string outputFormat_;
+	/// Does this class redefine the output format?
+	bool has_output_format_;
 	/** Base font. The paragraph and layout fonts are resolved against
 	    this font. This has to be fully instantiated. Attributes
 	    FONT_INHERIT, FONT_IGNORE, and FONT_TOGGLE are
@@ -332,7 +346,11 @@ protected:
 	/// Citation macros
 	std::map<CiteEngineType, std::map<std::string, std::string> > cite_macros_;
 	/// The default BibTeX bibliography style file
-	std::string cite_default_biblio_style_;
+	std::map<std::string, std::string> cite_default_biblio_style_;
+	/// Citation command aliases
+	std::map<std::string, std::string> cite_command_aliases_;
+	/// The maximum number of citations before "et al."
+	size_t maxcitenames_;
 	/// Whether full author lists are supported
 	bool cite_full_author_list_;
 	/// The possible citation styles
@@ -423,6 +441,8 @@ public:
 	///
 	std::string const & opt_enginetype() const { return opt_enginetype_; }
 	///
+	std::string const & citeFramework() const { return citeframework_; }
+	///
 	std::string const & opt_fontsize() const { return opt_fontsize_; }
 	///
 	std::string const & opt_pagestyle() const { return opt_pagestyle_; }
@@ -439,7 +459,7 @@ public:
 	///
 	docstring const & htmlstyles() const { return htmlstyles_; }
 	/// Looks for the layout of "highest level", other than Part (or other
-	/// layouts with a negative toc number), for use in constructing TOCs and 
+	/// layouts with a negative toc number), for use in constructing TOCs and
 	/// similar information.
 	Layout const & getTOCLayout() const;
 	/// the paragraph style to use for TOCs, Bibliography, etc
@@ -479,8 +499,9 @@ public:
 	/// returns true if the class has a ToC structure
 	bool hasTocLevels() const;
 	///
-	std::string const & getCiteFormat(CiteEngineType const & type,
-		std::string const & entry, std::string const & fallback = "") const;
+	std::string const getCiteFormat(CiteEngineType const & type,
+		std::string const & entry, bool const punct = true,
+		std::string const & fallback = "") const;
 	///
 	std::string const & getCiteMacro(CiteEngineType const & type,
 		std::string const & macro) const;
@@ -489,7 +510,13 @@ public:
 	///
 	std::vector<CitationStyle> const & citeStyles(CiteEngineType const &) const;
 	///
-	std::string const & defaultBiblioStyle() const { return cite_default_biblio_style_; }
+	std::map<std::string, std::string> const & defaultBiblioStyle() const
+	{ return cite_default_biblio_style_; }
+	///
+	std::map<std::string, std::string> const & citeCommandAliases() const
+	{ return cite_command_aliases_; }
+	/// The maximum number of citations before "et al."
+	size_t max_citenames() const { return maxcitenames_; }
 	///
 	bool const & fullAuthorList() const { return cite_full_author_list_; }
 protected:
@@ -501,6 +528,7 @@ private:
 	/// The only way to make a DocumentClass is to call this function.
 	friend DocumentClassPtr
 		getDocumentClass(LayoutFile const &, LayoutModuleList const &,
+				 LayoutModuleList const &,
 				 bool const clone);
 };
 
@@ -511,6 +539,7 @@ private:
 /// on the CutStack.
 DocumentClassPtr getDocumentClass(LayoutFile const & baseClass,
 			LayoutModuleList const & modlist,
+			LayoutModuleList const & celist,
 			bool const clone = false);
 
 /// convert page sides option to text 1 or 2
@@ -518,6 +547,9 @@ std::ostream & operator<<(std::ostream & os, PageSides p);
 
 /// current format of layout files
 extern int const LAYOUT_FORMAT;
+/// layout format for the current lyx file format (usually equal to
+/// LAYOUT_FORMAT)
+extern int const LYXFILE_LAYOUT_FORMAT;
 
 
 } // namespace lyx
