@@ -477,7 +477,9 @@ private:
 	/// from the default zoom pref
 	double zoom_ratio_ = 1.0;
 	/// Minimum zoom percentage
-	static int const zoom_min_ = 10;
+	int const zoom_min_ = 10;
+	/// Maximum zoom percentage
+	int const zoom_max_ = 1000;
 
 	// movability flag of all toolbars
 	bool toolbarsMovable_;
