@@ -20,7 +20,7 @@ string const escape_special_chars(string const & expr)
 
 	// $& is a ECMAScript format expression that expands to all
 	// of the current match
-#if defined(LYX_USE_CXX11) && defined(LYX_USE_STD_REGEX)
+#ifdef LYX_USE_STD_REGEX
 	// To prefix a matched expression with a single literal backslash, we
 	// need to escape it for the C++ compiler and use:
 	return lyx::regex_replace(expr, reg, "\\$&");
@@ -40,7 +40,7 @@ typedef map<string, string> InfoMap;
 // data entry matches the required regex_
 // This class is unfortunately copied from ../frontend_helpers.cpp, so we should
 // try to make sure to keep the two in sync.
-class RegexMatch : public unary_function<string, bool>
+class RegexMatch
 {
 public:
 	// re is used to construct an instance of lyx::regex.
